/*
    SPDX-FileCopyrightText: 2024 Dmitrii Fomchenkov <fomchenkovda@basealt.ru>
    SPDX-License-Identifier: GPL-2.0-or-later
*/
import QtQuick 2.15
import QtQuick.Controls 2.5 as QQC2
import QtQuick.Layouts 1.2
import org.kde.kirigami 2.15 as Kirigami

import org.kde.plasma.welcome 1.0

import org.kde.plasma.private.welcomedistro 1.0
import "../kf5/kpackage/kcms/kcm_landingpage/contents/ui"

GenericPage {
    heading: ""
    description: ""

    padding: -(Kirigami.Units.gridUnit * 2 + margins * 2)
    
    Item {
        id: item
        anchors.top: parent.top
        width: parent.implicitWidth
        height: Kirigami.Units.gridUnit * 2
    }
    
    RowLayout {
        anchors.top: item.bottom

        width: parent.width

        Kirigami.Icon {
            source: WelcomeDistro.distroLogo
            implicitWidth: Kirigami.Units.iconSizes.enormous
            implicitHeight: Kirigami.Units.iconSizes.enormous
        }

        ColumnLayout {
            Item { Layout.fillHeight: true }

            Kirigami.Heading {
                Layout.fillWidth: true
                text: i18ndc("plasma_applet_org.kde.plasma.welcomedistro", "@title", "Welcome to\n%1", WelcomeDistro.distroName)
                level: 1
                type: Kirigami.Heading.Type.Primary
                wrapMode: Text.Wrap
            }
            
            QQC2.Label {
                visible: WelcomeDistro.distroUrl !== ""
                text: "<a href='%1'>%1</a>".arg(WelcomeDistro.distroUrl)
                textFormat: Text.RichText
                onLinkActivated: Qt.openUrlExternally(link)

                HoverHandler { cursorShape: Qt.PointingHandCursor }
            }

            Item { Layout.fillHeight: true }
        }
    }

    ColumnLayout {
        anchors.centerIn: parent

        Kirigami.Heading {
            Layout.alignment: Qt.AlignHCenter
            text: i18ndc("plasma_applet_org.kde.plasma.welcomedistro", "@theme", "Theme")
            level: 5
        }

        RowLayout {
            Kirigami.FormLayout {
                width: parent.width

                RowLayout {
                    Item { width: parent.width }

                    Layout.alignment: Qt.AlignCenter
                    spacing: Kirigami.Units.gridUnit * 2

                    Thumbnail {
                        imageSource: WelcomeDistro.settingTheme.lightTheme.themePreviewPath
                        text: WelcomeDistro.settingTheme.lightTheme.themeName
                        checked: WelcomeDistro.settingTheme.defaultThemeId === WelcomeDistro.settingTheme.lightTheme.themeId

                        onToggled: WelcomeDistro.settingTheme.defaultThemeId = WelcomeDistro.settingTheme.lightTheme.themeId
                    }

                    Thumbnail {
                        imageSource: WelcomeDistro.settingTheme.darkTheme.themePreviewPath
                        text: WelcomeDistro.settingTheme.darkTheme.themeName
                        checked: WelcomeDistro.settingTheme.defaultThemeId === WelcomeDistro.settingTheme.darkTheme.themeId

                        onToggled: WelcomeDistro.settingTheme.defaultThemeId = WelcomeDistro.settingTheme.darkTheme.themeId 
                    }
                }
            }
         
        }
    }
}
